#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define pkg_suffix -test
%bcond_without test
%else
%define pkg_suffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-installer%{pkg_suffix}
Version:        0.7.0
Release:        2.3
Summary:        A library for installing Python wheels
License:        MIT
URL:            https://github.com/pypa/installer
Source:         https://files.pythonhosted.org/packages/source/i/installer/installer-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module flit-core}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module installer}
BuildRequires:  %{python_module pytest}
%endif
BuildArch:      noarch
%python_subpackages

%description
A library for installing Python wheels.

%prep
%autosetup -p1 -n installer-%{version}

%if !%{with test}
%build

export apython3=$(find %_bindir -name 'python3*[0-9]' -print -quit)
$apython3 -m flit_core.wheel

%endif

%if !%{with test}
%install
export PYTHONPATH=src
%python_expand $python -m installer -d %{buildroot} dist/*.whl
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/installer
%{python_sitelib}/installer-%{version}.dist-info
%endif

%changelog
* Wed Apr 26 2023 Dirk Müller <dmueller@suse.com>
- build with any python3 interpreter installed in the buildenv
* Mon Apr 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Use python311 to build if sle15_python_module_pythons is defined.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Tue Mar 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.7.0:
  * Improve handling of non-normalized .dist-info folders (#168)
  * Explicitly use policy=compat32 (#163)
  * Normalize RECORD file paths when parsing (#152)
  * Search wheels for .dist-info directories (#137)
  * Separate validation of RECORD (#147, #167)
- Only build the wheel once.
* Sat Feb 11 2023 Ben Greiner <code@bnavigator.de>
- Don't build for Python 3.6: It requires importlib.resources
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.6.0
  * Add support for Python 3.11
* Wed Jun 15 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.1:
  * No upstream changelog.
- Drop importlib-resources and setuptools from BuildRequires, we can
  bootstrap this package using only flit-core and itself.
- Inject multibuild to aid bootstrapping.
- Drop patch remove-mock.patch:
  * Included upstream.
* Mon Feb 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Add missing BR for importlib_resources
* Mon Feb 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Skip building for python2
* Thu Jan 20 2022 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for installer 0.3.0. (the highest
  supported version for PDM).
